@@ -187,9 +187,17 @@ class SQLMapping(object):
         for m_MappingFiles in self.m_SQL_MappingList:                           # 所有的SQL Mapping信息
             m_MappingFile_Contents = self.m_SQL_MappingList[m_MappingFiles]     # 具体的一个SQL Mapping文件
             for m_Mapping_Contents in m_MappingFile_Contents:                   # 具体的一个映射信息
-                if re.match(m_Mapping_Contents[0], m_TestScriptFileName):       # 文件名匹配
-                    for (m_Key, m_Value) in m_Mapping_Contents[1]:              # 内容遍历
-                        m_New_SQL = self.ReplaceSQL(m_New_SQL, m_Key, m_Value)
+                try:
+                    if re.match(m_Mapping_Contents[0], m_TestScriptFileName):       # 文件名匹配
+                        for (m_Key, m_Value) in m_Mapping_Contents[1]:              # 内容遍历
+                            m_New_SQL = self.ReplaceSQL(m_New_SQL, m_Key, m_Value)
+                except re.error as ex:
+                    print("[WARNING] Invalid regex pattern. " +
+                          "[" + str(m_Mapping_Contents[0]) + " : " + m_TestScriptFileName + " : " +
+                          m_MappingFiles + "]  " +
+                          repr(ex), file=self.Console)
+                    print("[WARNING] Your mapping config has been ignored.")
+                    self.m_SQL_MappingList = {}
         return m_New_SQL
 
 
@@ -338,7 +346,7 @@ def SQLAnalyze(p_SQLCommandPlainText):
 
             # 如果本行只有唯一的内容，就是段落终止符的话，本语句没有意义，不会执行；但是注释有意义
             # / 不能送给SQL解析器
-            if re.match(r'^/$', SQLCommands[m_nPos]):
+            if re.match(r'^(\s+)?/(\s+)?$', SQLCommands[m_nPos]):
                 SQLSplitResults.append("")
                 SQLSplitResultsWithComments.append(SQLCommandsWithComments[m_nPos])
                 if m_nPos == len(SQLCommands) - 1:
@@ -441,7 +449,7 @@ def SQLAnalyze(p_SQLCommandPlainText):
             m_NewSQLWithComments = SQLCommandsWithComments[m_nPos][m_NewSQLWithCommentsLastPos:]
             if re.match(r'(.*);(\s+)?$', SQLCommands[m_nPos]):  # 本行以；结尾
                 strRegexPattern = \
-                    r'^((\s+)?CREATE(\s+)|^(\s+)?REPLACE(\s+))(.*)?(FUNCTION|PROCEDURE)'
+                    r'^((\s+)?CREATE(\s+)|^(\s+)?REPLACE(\s+))((\s+)?(OR)?(\s+)?(REPLACE)?(\s+)?)?(FUNCTION|PROCEDURE)'
                 strRegexPattern2 = \
                     r'^(\s+)?DECLARE(\s+)|^(\s+)?BEGIN(\s+)'
                 if not re.match(strRegexPattern, SQLCommands[m_nPos], re.IGNORECASE) and \
@@ -486,7 +494,7 @@ def SQLAnalyze(p_SQLCommandPlainText):
                 m_bInMultiLineSQL = True
         else:  # 工作在多行语句中
             # 本行只有唯一的内容，就是段落终止符的话，语句应该可以提交了
-            if re.match(r'^/$', SQLCommands[m_nPos]):
+            if re.match(r'^(\s+)?/(\s+)?$', SQLCommands[m_nPos]):
                 SQLSplitResults.append(m_NewSQL)
                 # 注释信息包含/符号
                 SQLSplitResultsWithComments.append(m_NewSQLWithComments + "\n/")
@@ -534,7 +542,7 @@ def SQLAnalyze(p_SQLCommandPlainText):
                 if re.match(r'(.*);(\s+)?$', SQLCommands[m_nPos]):  # 本行以；结尾
                     # 查找这个多行语句是否就是一个存储过程
                     strRegexPattern = \
-                        r'^((\s+)?CREATE(\s+)|^(\s+)?REPLACE(\s+))(.*)?(FUNCTION|PROCEDURE)'
+                        r'^((\s+)?CREATE(\s+)|^(\s+)?REPLACE(\s+))((\s+)?(OR)?(\s+)?(REPLACE)?(\s+)?)?(FUNCTION|PROCEDURE)'
                     strRegexPattern2 = \
                         r'^(\s+)?DECLARE(\s+)|^(\s+)?BEGIN(\s+)'
                     if not re.match(strRegexPattern, m_NewSQL, re.IGNORECASE) and \
